@@ -8,16 +8,17 @@ class DocumentNotFound(Exception):
 
 
 class WordPressReader(object):
-    def __init__(
-            self,
+    def __init__(self,
             host,
             user,
             passwd,
             db,
-            table_prefix,
             internal_cms_link_prefix,
-            content_path_prefix):
+            content_path_prefix,
+            port=3306,
+            table_prefix='wp'):
         self.host = host
+        self.port = port
         self.user = user
         self.passwd = passwd
         self.db = db
@@ -26,29 +27,41 @@ class WordPressReader(object):
         self.content_path_prefix = content_path_prefix
         self._connection = None
 
+    def _connect(self):
+        self._connection = MySQLdb.connect(
+            host=self.host,
+            port=self.port,
+            user=self.user,
+            passwd=self.passwd,
+            db=self.db)
+
     @property
     def connection(self):
         if not self._connection:
-            self._connection = MySQLdb.connect(
-                host=self.host,
-                user=self.user,
-                passwd=self.passwd,
-                db=self.db)
+            self._connect()
         return self._connection
 
+    def query(self, *args):
+        try:
+            cursor = self.connection.cursor()
+            cursor.execute(*args)
+        except (AttributeError, MySQLdb.OperationalError):
+            self._connect()
+            cursor = self.connection.cursor()
+            cursor.execute(*args)
+        self.connection.commit()
+        return cursor
+
     def get_document_by_slug(self, wp_slug):
         return WordPressDocument.from_wp_slug(
-            self.connection,
+            self,
             self.table_prefix,
             self.internal_cms_link_prefix,
             self.content_path_prefix,
             wp_slug)
 
     def get_parent_by_id(self, wp_id):
-        return WordPressParent.from_wp_id(
-            self.connection,
-            self.table_prefix,
-            wp_id)
+        return WordPressParent.from_wp_id(self, self.table_prefix, wp_id)
 
 
 class WordPressDocument(object):
@@ -74,19 +87,17 @@ class WordPressDocument(object):
     @classmethod
     def from_wp_slug(
             cls,
-            connection,
+            reader,
             table_prefix,
             internal_cms_link_prefix,
             content_path_prefix,
             wp_slug):
-        cursor = connection.cursor()
-
-        query = """
+        sql = """
             SELECT post_title AS title, post_content AS content
             FROM %s_posts
             WHERE post_name = %%s
             """ % (table_prefix)
-        cursor.execute(query, (wp_slug,))
+        cursor = reader.query(sql, (wp_slug,))
         record = cursor.fetchone()
         if not record:
             raise DocumentNotFound(
@@ -109,16 +120,14 @@ class WordPressParent(object):
         self.children = children
 
     @classmethod
-    def from_wp_id(cls, connection, table_prefix, wp_id):
-        cursor = connection.cursor()
-
-        parent_query = """
+    def from_wp_id(cls, reader, table_prefix, wp_id):
+        parent_sql = """
             SELECT post_title AS title
             FROM %s_posts
             WHERE ID = %%s
             AND post_status = 'publish'
             """ % (table_prefix)
-        cursor.execute(parent_query, (wp_id,))
+        cursor = reader.query(parent_sql, (wp_id,))
         parent_record = cursor.fetchone()
         if not parent_record:
             raise DocumentNotFound(
@@ -126,14 +135,14 @@ class WordPressParent(object):
                 'or is not published' % (wp_id))
         title = parent_record[0]
 
-        children_query = """
+        children_sql = """
             SELECT post_title AS title, post_name AS slug
             FROM %s_posts
             WHERE post_parent = %%s
             AND post_status = 'publish'
             ORDER BY menu_order
             """ % (table_prefix)
-        cursor.execute(children_query, (wp_id,))
+        cursor = reader.query(children_sql, (wp_id,))
         children = []
         if cursor.rowcount > 0:
             child_records = []
